@@ -23,7 +23,7 @@ from jupyter_server.services.kernels.handlers import (
 from jupyter_server.services.kernels.kernelmanager import MappingKernelManager
 from jupyter_server.services.kernelspecs.handlers import MainKernelSpecHandler
 from traitlets import Dict as tDict
-from traitlets import Integer, Unicode, default
+from traitlets import Integer, Bool, Unicode, default
 from traitlets.config.application import Application
 
 from .handlers import (
@@ -83,6 +83,7 @@ class CosappModuleServer(Application):
         "static": "CosappModuleServer.static_root",
         "f": "CosappModuleServer.file",
         "url_prefix": "CosappModuleServer.url_prefix",
+        "open_browser": "CosappModuleServer.open_browser",
     }
     connection_dir_root = Unicode(
         config=True,
@@ -101,6 +102,8 @@ class CosappModuleServer(Application):
 
     url_prefix = Unicode("", config=True, help=("Prefix to append to handlers URL."))
 
+    open_browser = Bool(True, config=True, help=("True if local web browser is used, False otherwise"))
+
     @default("connection_dir_root")
     def _default_connection_dir(self):
         return tempfile.gettempdir()
@@ -183,9 +186,12 @@ class CosappModuleServer(Application):
             default_handler_class=Default404Handler,
         )
         app.listen(self.port)
-        self.log.info(f"CoSApp server listening on port {self.port}.")
+        url = f"http://localhost:{self.port}{self.url_prefix}/"
+        self.log.info(f"CoSApp server listening on port {self.port}")
+        self.log.info(f"Address: {url}")
         try:
-            webbrowser.open(f"http://localhost:{self.port}{self.url_prefix}/")
+            if self.open_browser:
+                webbrowser.open(url)
             logging.getLogger("tornado.access").disabled = True
             tornado.ioloop.IOLoop.current().start()
 
