@@ -3,16 +3,11 @@
 
 # Copyright (c) CoSApp Team.
 
-
-import json
-import os
-from typing import Any, Dict, List, Type, Union
-from weakref import ReferenceType, ref
-
+from typing import Union, List
+from traitlets import Unicode
 
 from cosapp.systems import System
 
-from traitlets import Unicode
 from cosapp_lab.widgets.base import BaseWidget
 from cosapp_lab.widgets.chartwidget import ChartElement
 from cosapp_lab.widgets.controllerwidget import ControllerComponent
@@ -36,9 +31,12 @@ class SysExplorer(BaseWidget):
         self.register(ChartElement, **kwargs)
         self.register(StructureComponent, **kwargs)
         self.register(ControllerComponent, **kwargs)
-        add_shape = kwargs.pop("add_shape", None)
-        source = kwargs.pop("source", None)
-        self.register(GeometryComponent, add_shape=add_shape, source=source, **kwargs)
+        geom_options = dict(
+            get_shapes = kwargs.pop("get_shapes", None),
+            add_shape = kwargs.pop("add_shape", None),  # to be deprecated
+            source = kwargs.pop("source", None),
+        )
+        self.register(GeometryComponent, **geom_options, **kwargs)
         self.register(WidgetView, **kwargs)
         self.register(DocumentView, **kwargs)
         self.register(SystemInfoComponent, **kwargs)
