@@ -1,3 +1,4 @@
+import { IDict } from './../widgets/redux/types';
 import {
   Kernel,
   ServerConnection,
@@ -17,12 +18,12 @@ class CosappMain {
   private _kernelManager: KernelManager;
   private _widgetManager: WidgetManager;
   private _kernelModel: Kernel.IModel;
-  private _statusElement: HTMLElement
+  private _statusElement: HTMLElement;
   constructor(baseUrl: string, wsUrl: string, cosappModule: string) {
     this._baseUrl = baseUrl;
     this._wsUrl = wsUrl;
     this._cosappModule = cosappModule;
-    this._statusElement = document.getElementById("cosapp_loading_status")
+    this._statusElement = document.getElementById('cosapp_loading_status');
     this._kernelModel = {
       name: window.sessionStorage.getItem('adso_kernel_name'),
       id: window.sessionStorage.getItem('adso_kernel_id'),
@@ -83,18 +84,29 @@ class CosappMain {
     });
     let kernelStatus = false;
     if (this._kernelModel.id && this._kernelModel.name) {
-      this._statusElement.innerText = "Checking existing kernel"
+      this._statusElement.innerText = 'Checking existing kernel';
       kernelStatus = await this.checkKernelAlive(this._kernelModel.id);
     }
 
     if (kernelStatus) {
-      this._statusElement.innerText = "Connecting to existing kernel"
+      this._statusElement.innerText = 'Connecting to existing kernel';
       this._kernel = await this._kernelManager.connectTo({
         model: this._kernelModel,
       });
     } else {
-      this._statusElement.innerText = "Starting new kernel"
-      this._kernel = await this._kernelManager.startNew();
+      this._statusElement.innerText = 'Starting new kernel';
+      let configData : IDict<string> = {}
+      const el = document.getElementById('cosapp-lab-config-data');
+      if (el) {
+        configData = JSON.parse(el.textContent || '{}')
+      }
+      let kernelConfig = {}
+      if ("kernel" in configData && configData.kernel )
+      {
+        kernelConfig["name"] = configData.kernel
+      }
+      this._kernel = await this._kernelManager.startNew(kernelConfig);
+      
       window.sessionStorage.setItem(
         'adso_kernel_name',
         this._kernel.model.name
@@ -116,7 +128,7 @@ class CosappMain {
         status_indicator_off.style.display = 'none';
       }
     });
-    this._statusElement.innerText = "Getting bootstrap code"
+    this._statusElement.innerText = 'Getting bootstrap code';
     const remoteData = await this.getCode(this._cosappModule);
 
     const { title, code } = remoteData;
@@ -126,18 +138,21 @@ class CosappMain {
     }
 
     this._widgetManager = new WidgetManager(this._kernel);
-    this._statusElement.innerText = "Executing bootstrap code"
+    this._statusElement.innerText = 'Executing bootstrap code';
     const execution = this._kernel.requestExecute({ code });
 
     execution.onIOPub = async (msg) => {
       console.log('msg', msg.content);
-      if (KernelMessage.isStreamMsg(msg) || KernelMessage.isExecuteInputMsg(msg)) {
+      if (
+        KernelMessage.isStreamMsg(msg) ||
+        KernelMessage.isExecuteInputMsg(msg)
+      ) {
         console.log('result', msg.content);
       }
       if (KernelMessage.isDisplayDataMsg(msg)) {
         const widgetData: any =
           msg.content.data['application/vnd.jupyter.widget-view+json'];
-        this._statusElement.innerText = "Done, starting interface"
+        this._statusElement.innerText = 'Done, starting interface';
         if (widgetData !== undefined && widgetData.version_major === 2) {
           const model = this._widgetManager.get_model(widgetData.model_id);
           if (model !== undefined) {
@@ -147,12 +162,12 @@ class CosappMain {
           }
         }
       } else if (KernelMessage.isErrorMsg(msg)) {
-        let errorText = msg.content.ename + '\n'
-        errorText += msg.content.evalue + '\n'
+        let errorText = msg.content.ename + '\n';
+        errorText += msg.content.evalue + '\n';
         console.log('error', msg.content);
-        this._statusElement.style.width = '90%'
-        this._statusElement.style.color = 'red'
-        this._statusElement.innerText = errorText
+        this._statusElement.style.width = '90%';
+        this._statusElement.style.color = 'red';
+        this._statusElement.innerText = errorText;
       }
     };
   }
@@ -169,15 +184,10 @@ function main() {
   console.log('BASEURL', BASEURL, 'COSAPP_MODULE', COSAPP_MODULE);
 
   let WSURL;
-  if (window.location.protocol.startsWith('https://')) {
-    const temp = BASEURL.replace('https://', '');
-    WSURL = 'wss://' + temp;
-    // WSURL = "wss://" + BASEURL;
+  if (BASEURL.startsWith('https://')) {
+    WSURL = BASEURL.replace('https://', 'wss://');
   } else {
-    const temp = BASEURL.replace('http://', '');
-
-    WSURL = 'ws://' + temp;
-    // WSURL = "ws://" + BASEURL;
+    WSURL = BASEURL.replace('http://', 'ws://');
   }
 
   const app = new CosappMain(BASEURL, WSURL, COSAPP_MODULE);
